import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:unicons/unicons.dart';

import 'package:random/cubit/game_cubit.dart';
import 'package:random/models/game_data.dart';
import 'package:random/ui/widgets/game_board.dart';

class GamePage extends StatefulWidget {
  const GamePage({super.key});

  @override
  State<GamePage> createState() => _GamePageState();
}

void createNewGame(GameCubit gameCubit, int boardSize) {
  final GameData newGame = GameData.createRandom(boardSize);
  gameCubit.updateGameState(newGame);
}

class _GamePageState extends State<GamePage> {
  @override
  Widget build(BuildContext context) {
    return BlocBuilder<GameCubit, GameState>(
      builder: (context, gameState) {
        const boardSize = 6;
        const double boardWidgetWidth = 300;
        const double boardWidgetHeight = 300;

        final GameCubit gameCubit = BlocProvider.of<GameCubit>(context);

        return Column(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            gameState.game != null
                ? GameBoardWidget(
                    gameData: gameState.game!,
                    size: Size(boardWidgetWidth, boardWidgetHeight),
                  )
                : SizedBox.shrink(),
            IconButton(
              onPressed: () {
                createNewGame(gameCubit, boardSize);
              },
              icon: Icon(UniconsSolid.star),
              color: Colors.white,
            ),
          ],
        );
      },
    );
  }
}
