import 'package:flutter/material.dart';

import 'package:random/models/game_data.dart';
import 'package:random/ui/painters/cell_painter.dart';

class GameBoardWidget extends StatefulWidget {
  const GameBoardWidget({
    super.key,
    required this.gameData,
    required this.size,
  });

  final GameData gameData;
  final Size size;

  @override
  State<GameBoardWidget> createState() => _GameBoardWidgetState();
}

class _GameBoardWidgetState extends State<GameBoardWidget> {
  @override
  Widget build(BuildContext context) {
    final widgetWidth = widget.size.width;
    final widgetHeight = widget.size.height;

    final rowsCount = widget.gameData.board.length;
    final columnsCount = widget.gameData.board[0].length;
    print('counts: rows=' + rowsCount.toString() + ' / columns=' + columnsCount.toString());

    final cellWidth = widgetWidth / columnsCount;
    final cellHeight = widgetHeight / rowsCount;
    print('cell: width=' + cellWidth.toString() + ' / height=' + cellHeight.toString());

    final List<Widget> cells = [];

    for (var y = 0; y < rowsCount; y++) {
      for (var x = 0; x < columnsCount; x++) {
        final GameDataItem item = widget.gameData.board[y][x];

        final Widget cellContent = CustomPaint(
          size: Size(cellWidth, cellHeight),
          willChange: false,
          painter: CellPainter(value: item.value),
        );

        final Widget cellWidget = Positioned(
          left: (x * cellWidth).toDouble(),
          top: (y * cellHeight).toDouble(),
          child: Container(
            width: cellWidth,
            height: cellHeight,
            child: cellContent,
          ),
        );

        cells.add(cellWidget);
      }
    }

    return Container(
      width: widgetWidth,
      height: widgetHeight,
      color: Colors.grey,
      child: Stack(
        children: cells,
      ),
    );
  }
}
